#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://hostap.epitest.fi/wpa_supplicant/
# last revised     : 13.09.2011

set -e -u -x

softname='wpa-supplicant'
softnamesrc='wpa_supplicant'
softversion='0.7.3'
packageversion='72.3'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softnamesrc-$softversion.tar.gz"
src="$buildir/$softnamesrc-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://hostap.epitest.fi/releases/"$softnamesrc-$softversion".tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/sbin
mkdir -p $dest/etc/dbus-1/system.d/
mkdir -p $dest/usr/share/dbus-1/system-services
mkdir -p $dest/usr/man/man5
mkdir -p $dest/usr/man/man8
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
              |-----handy-ruler------------------------------------------------------|
wpa-supplicant: wpa-supplicant - A WPA Supplicant Tool
wpa-supplicant:
wpa-supplicant: wpa_supplicant is a WPA Supplicant for Linux, BSD, Mac OS X, and
wpa-supplicant: Windows with support for WPA and WPA2 (IEEE 802.11i / RSN). It is
wpa-supplicant: suitable for both desktop/laptop computers and embedded systems.
wpa-supplicant: Supplicant is the IEEE 802.1X/WPA component that is used in the client
wpa-supplicant: stations. It implements key negotiation with a WPA Authenticator and
wpa-supplicant: it controls the roaming and IEEE 802.11 authentication/association of
wpa-supplicant: the wlan driver.
wpa-supplicant: 
wpa-supplicant:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

patch -p1 < ../dbus.patch
#patch -p1 < ../wpa_supplicant-openssl-more-algs.patch
patch -p1 < ../wpa_supplicant-dbus-service-file-args.patch

cd wpa_supplicant

# add configuration from our config
cp $buildir/config .config

# build
	
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    make

	# copy executable files
	cp wpa_cli wpa_supplicant wpa_passphrase $dest/usr/sbin
	cd $dest/usr/sbin
	ln -s wpa_cli wpa-cli
	ln -s wpa_supplicant wpa-supplicant
	ln -s wpa_passphrase wpa-passphrase

    # generate dbus control policy and service files
	cp $src/wpa_supplicant/dbus/dbus-wpa_supplicant.conf $dest/etc/dbus-1/system.d/

	cp $src/wpa_supplicant/dbus/*.service $dest/usr/share/dbus-1/system-services/

	# install conf file
	cp $src/wpa_supplicant/wpa_supplicant.conf $dest/etc/wpa_supplicant.conf.new
	#cp $buildir/wpa_supplicant.conf $dest/etc/wpa_supplicant.conf.new
	
	# man pages
	cp -a $src/wpa_supplicant/doc/docbook/*.5 $dest/usr/man/man5
	cp -a $src/wpa_supplicant/doc/docbook/*.8 $dest/usr/man/man8

	chown -R root:root $dest

cat <<EOINS > $dest/install/doinst.sh
# Handle the incoming configuration files:
config() {
  for infile in \$1; do
    NEW="\$infile"
    OLD="\`dirname \$NEW\`/\`basename \$NEW .new\`"
    # If there's no config file by that name, mv it over:
    if [ ! -r \$OLD ]; then
      mv \$NEW \$OLD
    elif [ "\`cat \$OLD | md5sum\`" = "\`cat \$NEW | md5sum\`" ]; then
      # toss the redundant copy
      rm \$NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}
config etc/wpa_supplicant.conf.new

EOINS

# This should only be read/write by root:
chmod 600 $dest/etc/wpa_supplicant.conf.new

# add 'default' files
cd $src/wpa_supplicant
    cp -a \
      ChangeLog ../COPYING README README-WPS *.txt examples \
      $dest/usr/doc/$softname-$softversion
  
# Compress Man & Info Pages
gzip -9 $dest/usr/man/man?/*

# Strip
( cd $dest
find $dest | xargs -r file | grep "executable\|shared object" | grep ELF |\
	cut -f 1 -d : | xargs -r strip --strip-unneeded
find $dest | xargs -r file | grep "current ar archive" |\
	cut -f 1 -d : | xargs -r strip -g
)

# Buildscript
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp $buildir/dbus.patch $dest/usr/src/$softname-$softversion
cp $buildir/wpa_supplicant-openssl-more-algs.patch $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "dbus,libnl,ncurses,openssl,readline" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/n/wpa-supplicant/source/build-wpa-supplicant.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/n/wpa-supplicant/source/dbus.patch >> $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/n/wpa-supplicant/source/wpa_supplicant-openssl-more-algs.patch >> $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
